@@ -14,6 +14,7 @@ import sys
 
 import click
 from rich import box
+from rich.errors import NotRenderableError
 from rich.table import Table as rTable
 
 from SoftLayer.CLI import exceptions
@@ -69,7 +70,6 @@ def format_output(data, fmt='table', theme=None):  # pylint: disable=R0911,R0912
         return output
 
     # fallback, convert this odd object to a string
-    # print(f"Casting this to string {data}")
     return str(data)
 
 
@@ -243,7 +243,10 @@ def confirm(prompt_str, default=False):
         default_str = 'n'
         prompt = '%s [y/N]' % prompt_str
 
-    ans = click.prompt(prompt, default=default_str, show_default=False)
+    try:
+        ans = click.prompt(prompt, default=default_str, show_default=False)
+    except click.exceptions.Abort:
+        return False
     if ans.lower() in ('y', 'yes', 'yeah', 'yup', 'yolo'):
         return True
 
@@ -253,17 +256,18 @@ def confirm(prompt_str, default=False):
 def no_going_back(confirmation):
     """Show a confirmation to a user.
 
-    :param confirmation str: the string the user has to enter in order to
-                             confirm their action.
+    :param confirmation str: the string the user has to enter in order to confirm their action.
     """
     if not confirmation:
         confirmation = 'yes'
 
-    prompt = ('This action cannot be undone! Type "%s" or press Enter '
-              'to abort' % confirmation)
+    prompt = f"This action cannot be undone! Type '{confirmation}' or press Enter to abort"
 
-    ans = click.prompt(prompt, default='', show_default=False)
-    if ans.lower() == str(confirmation):
+    try:
+        ans = click.prompt(prompt, default='', show_default=False)
+    except click.exceptions.Abort:
+        return False
+    if ans.lower() == str(confirmation).lower():
         return True
 
     return False
@@ -319,12 +323,16 @@ class Table(object):
         self.sortby = None
         self.title = title
         # Used to print a message if the table is empty
-        self.empty_message = None
+        self.empty_message = "-"
 
     def __bool__(self):
         """Useful for seeing if the table has any rows"""
         return len(self.rows) > 0
 
+    def __str__(self):
+        """A Table should only be cast to a string if its empty"""
+        return self.empty_message
+
     def set_empty_message(self, message):
         """Sets the empty message for this table for env.fout
 
@@ -393,7 +401,15 @@ class Table(object):
             table.add_column(col, justify=justify, style=style)
 
         for row in self.rows:
-            table.add_row(*row)
+            try:
+                table.add_row(*row)
+            # Generally you will see this if one of the columns in the row is a list or dict
+            except NotRenderableError:
+                forced_row = []
+                for i in row:
+                    forced_row.append(str(i))
+                table.add_row(*forced_row)
+
         return table
 
 
